==> carapace-bin-1.5.7.tar.gz: carapace-bin-1.5.7/docs/src/SUMMARY.md <==
# Summary

- [carapace-bin](./carapace-bin.md)
  - [Install](./install.md)
    - [Selfupdate](./install/selfupdate.md)
  - [Setup](./setup.md)
    - [Environment](./setup/environment.md)
    - [UserConfigDir](./setup/userConfigDir.md)
  - [Completers](./completers.md)
  - [Style](./style.md)
  - [Bridges](./bridges.md)
  - [Spec](./spec.md)
    - [User](./spec/user.md)
    - [Bridge](./spec/bridge.md)
    - [Embed](./spec/embed.md)
    - [Run](./spec/run.md)
    - [Shim](./spec/shim.md)
    - [Scrape](./spec/scrape.md)
    - [Codegen](./spec/codegen.md)
    - [Examples](./spec/examples.md)
    - [Macros](./spec/macros.md)
  - [Overlay](./overlay.md)
  - [Variable](./variable.md)
    - [Conditions](./variable/conditions.md)
  - [Development](./development.md)
    - [Project Layout](./development/projectLayout.md)
    - [Build](./development/build.md)
    - [Docker](./development/docker.md)
    - [Creating Completers](./development/creatingCompleters.md)
      - [Manually](./development/creatingCompleters/manually.md)
      - [Parsing](./development/creatingCompleters/parsing.md)
      - [Scraping](./development/creatingCompleters/scraping.md)
      - [Examples](./development/creatingCompleters/examples.md)
    - [Updating Completers](./development/updatingCompleters.md)
    - [Best Practices](./development/bestPractices.md)
      - [Coupled Actions](./development/bestPractices/coupledActions.md)
    - [Tools](./development/tools.md)
      - [carapace-fmt](./development/tools/carapace-fmt.md)
      - [carapace-lint](./development/tools/carapace-lint.md)
      - [carapace-parse](./development/tools/carapace-parse.md)
      - [carapace-generate](./development/tools/carapace-generate.md)
  - [Release Notes](./release_notes.md)
    - [v1.x](./release_notes/v1.x.md)
    - [v1.5](./release_notes/v1.5.md)
    - [v1.4](./release_notes/v1.4.md)
    - [v1.3](./release_notes/v1.3.md)
    - [v1.2](./release_notes/v1.2.md)
    - [v1.1](./release_notes/v1.1.md)
    - [v1.0](./release_notes/v1.0.md)
    - [v0.30](./release_notes/v0.30.md)
    - [v0.29](./release_notes/v0.29.md)
    - [v0.28](./release_notes/v0.28.md)
    - [v0.27](./release_notes/v0.27.md)
    - [v0.26](./release_notes/v0.26.md)
    - [v0.25](./release_notes/v0.25.md)
    - [v0.24](./release_notes/v0.24.md)
    - [v0.23](./release_notes/v0.23.md)
    - [v0.22](./release_notes/v0.22.md)
    - [v0.21](./release_notes/v0.21.md)
    - [v0.20](./release_notes/v0.20.md)
    - [v0.19](./release_notes/v0.19.md)
    - [v0.18](./release_notes/v0.18.md)
    - [v0.17](./release_notes/v0.17.md)
    - [v0.16](./release_notes/v0.16.md)
    - [v0.15](./release_notes/v0.15.md)
    - [v0.14](./release_notes/v0.14.md)
    - [v0.13](./release_notes/v0.13.md)
    - [v0.12](./release_notes/v0.12.md)
    - [v0.11](./release_notes/v0.11.md)

==> carapace-bin-1.6.1.tar.gz: carapace-bin-1.6.1/docs/src/SUMMARY.md <==
# Summary

- [carapace-bin](./carapace-bin.md)
  - [Install](./install.md)
    - [Selfupdate](./install/selfupdate.md)
  - [Setup](./setup.md)
    - [Environment](./setup/environment.md)
    - [UserConfigDir](./setup/userConfigDir.md)
  - [Groups](./groups.md)
  - [Variants](./variants.md)
  - [Choices](./choices.md)
  - [Completers](./completers.md)
  - [Style](./style.md)
  - [Spec](./spec.md)
    - [User](./spec/user.md)
    - [Bridge](./spec/bridge.md)
    - [Embed](./spec/embed.md)
    - [Run](./spec/run.md)
    - [Shim](./spec/shim.md)
    - [Scrape](./spec/scrape.md)
    - [Codegen](./spec/codegen.md)
    - [Examples](./spec/examples.md)
    - [Macros](./spec/macros.md)
  - [Overlay](./overlay.md)
  - [Variable](./variable.md)
    - [Conditions](./variable/conditions.md)
  - [Development](./development.md)
    - [Project Layout](./development/projectLayout.md)
    - [Build](./development/build.md)
    - [Docker](./development/docker.md)
    - [Creating Completers](./development/creatingCompleters.md)
      - [Manually](./development/creatingCompleters/manually.md)
      - [Parsing](./development/creatingCompleters/parsing.md)
      - [Scraping](./development/creatingCompleters/scraping.md)
      - [Examples](./development/creatingCompleters/examples.md)
    - [Updating Completers](./development/updatingCompleters.md)
    - [Best Practices](./development/bestPractices.md)
      - [Coupled Actions](./development/bestPractices/coupledActions.md)
    - [Tools](./development/tools.md)
      - [carapace-fmt](./development/tools/carapace-fmt.md)
      - [carapace-lint](./development/tools/carapace-lint.md)
      - [carapace-parse](./development/tools/carapace-parse.md)
      - [carapace-generate](./development/tools/carapace-generate.md)
  - [Release Notes](./release_notes.md)
    - [v1.x](./release_notes/v1.x.md)
    - [v1.6](./release_notes/v1.6.md)
    - [v1.5](./release_notes/v1.5.md)
    - [v1.4](./release_notes/v1.4.md)
    - [v1.3](./release_notes/v1.3.md)
    - [v1.2](./release_notes/v1.2.md)
    - [v1.1](./release_notes/v1.1.md)
    - [v1.0](./release_notes/v1.0.md)
    - [v0.30](./release_notes/v0.30.md)
    - [v0.29](./release_notes/v0.29.md)
    - [v0.28](./release_notes/v0.28.md)
    - [v0.27](./release_notes/v0.27.md)
    - [v0.26](./release_notes/v0.26.md)
    - [v0.25](./release_notes/v0.25.md)
    - [v0.24](./release_notes/v0.24.md)
    - [v0.23](./release_notes/v0.23.md)
    - [v0.22](./release_notes/v0.22.md)
    - [v0.21](./release_notes/v0.21.md)
    - [v0.20](./release_notes/v0.20.md)
    - [v0.19](./release_notes/v0.19.md)
    - [v0.18](./release_notes/v0.18.md)
    - [v0.17](./release_notes/v0.17.md)
    - [v0.16](./release_notes/v0.16.md)
    - [v0.15](./release_notes/v0.15.md)
    - [v0.14](./release_notes/v0.14.md)
    - [v0.13](./release_notes/v0.13.md)
    - [v0.12](./release_notes/v0.12.md)
    - [v0.11](./release_notes/v0.11.md)
